@@ -1,4 +1,4 @@
-`getsplineMatrices` <- 
+`getsplineMatrices` <-
 function(
 	my.matrices,
 	my.matrix.content_area.progression,
@@ -23,15 +23,15 @@ function(
 		if (is.null(my.order)) my.order <- (2:length(my.matrix.time.progression))-1
 		if (my.exact.grade.progression.sequence) my.order <- length(my.matrix.time.progression)-1
 		for (i in seq_along(my.order)) {
-			tmp.df[i,1] <- identical(my.matrix@Content_Areas[[1]], tail(my.matrix.content_area.progression, my.order[i]+1)) & 
-					identical(my.matrix@Grade_Progression[[1]], as.character(tail(my.matrix.grade.progression, my.order[i]+1))) & 
-					identical(my.matrix@Time[[1]], as.character(tail(my.matrix.time.progression, my.order[i]+1))) &
-					identical(all.equal(as.numeric(my.matrix@Time_Lags[[1]]), as.numeric(tail(my.matrix.time.progression.lags, my.order[i]))), TRUE) &
+			tmp.df[i,1L] <- identical(my.matrix@Content_Areas[[1L]], tail(my.matrix.content_area.progression, my.order[i]+1L)) &&
+					identical(my.matrix@Grade_Progression[[1L]], as.character(tail(my.matrix.grade.progression, my.order[i]+1L))) &&
+					identical(my.matrix@Time[[1L]], as.character(tail(my.matrix.time.progression, my.order[i]+1L))) &&
+					identical(all.equal(as.numeric(my.matrix@Time_Lags[[1L]]), as.numeric(tail(my.matrix.time.progression.lags, my.order[i]))), TRUE) &&
 					identical(names(my.matrix@Version[['Matrix_Information']][['SGPt']][['VARIABLES']]), names(my.matrix.time.dependency))
-			tmp.df[i,2] <-	my.order[i]
-			tmp.df[i,3] <- tail(my.matrix@Grade_Progression[[1]], 1)
+			tmp.df[i,2L] <- my.order[i]
+			tmp.df[i,3L] <- tail(my.matrix@Grade_Progression[[1L]], 1L)
 		}
-		names(tmp.df) <- c("Matrix_TF", "Order", "Grade")
+		setnames(tmp.df, c("Matrix_TF", "Order", "Grade"))
 		return(tmp.df)
 	} ### END splineMatrix_equality
 
@@ -53,14 +53,14 @@ function(
 		if (what.to.return=="MATRICES") {
 			if (is.null(my.matrix.order)) my.matrix.order <- length(my.matrix.time.progression.lags)
 			my.tmp.index <- which(sapply(lapply(my.matrices, splineMatrix_equality, my.order=my.matrix.order), function(x) x[['Matrix_TF']]))
-			if (length(my.tmp.index)==0) {
-				stop(paste("\tNOTE: No splineMatrix exists with designated content_area.progression:", paste(my.matrix.content_area.progression, collapse=", "), "year.progression:", 
+			if (length(my.tmp.index) == 0L) {
+				stop(paste("\tNOTE: No splineMatrix exists with designated content_area.progression:", paste(my.matrix.content_area.progression, collapse=", "), "year.progression:",
 					paste(my.matrix.time.progression, collapse=", "), "and grade.progression", paste(my.matrix.grade.progression, collapse=", ")))
 			}
-			if (length(my.tmp.index)>1) {
+			if (length(my.tmp.index) > 1L) {
 				if (!return.multiple.matrices) {
-					stop(paste("\tNOTE: Multiple splineMatrix objects exists with designated content_area.progression:", paste(my.matrix.content_area.progression, collapse=", "), 
-					"year.progression:", paste(my.matrix.time.progression, collapse=", "), "grade.progression:", paste(my.matrix.grade.progression, collapse=", "), 
+					stop(paste("\tNOTE: Multiple splineMatrix objects exists with designated content_area.progression:", paste(my.matrix.content_area.progression, collapse=", "),
+					"year.progression:", paste(my.matrix.time.progression, collapse=", "), "grade.progression:", paste(my.matrix.grade.progression, collapse=", "),
 					"time.progression.lags:", paste(my.matrix.time.progression.lags, collapse=", ")))
 				} else return(my.matrices[my.tmp.index])
 			} else {
@@ -85,7 +85,7 @@ function(
 	}
 
 	if (what.to.return=="MATRICES") {
-		if (return.highest.order.matrix) tmp.orders <- tail(tmp.orders, 1)
+		if (return.highest.order.matrix) tmp.orders <- tail(tmp.orders, 1L)
 		return(lapply(tmp.orders, function(x) getsplineMatrix(my.matrix.order=x)))
 	}
 } ### END getsplineMatrices
