@@ -35,6 +35,7 @@ function(sgp_object,
 		sgPlot.folder="Visualizations/studentGrowthPlots",
 		sgPlot.folder.names="number",
 		sgPlot.fan=TRUE,
+		sgPlot.custom.trajectory=FALSE,
 		sgPlot.sgp.targets=FALSE,
 		sgPlot.sgp.targets.timeframe=3,
 		sgPlot.anonymize=FALSE,
@@ -368,7 +369,7 @@ if ("studentGrowthPlot" %in% plot.types) {
 
 	get.next.content_area <- function(grade, content_area, increment) {
 		if (!is.null(tmp.domain <- SGP::SGPstateData[[state]][["Student_Report_Information"]][["Content_Areas_Domains"]][[content_area]]) & increment != 0 & !is.na(grade)) {
-			if (!is.numeric(type.convert(grade))) {
+			if (!is.numeric(type.convert(grade, as.is=FALSE))) {
 				tmp.index <- which(SGP::SGPstateData[[state]][["SGP_Configuration"]][["content_area.projection.sequence"]][[tmp.domain]] == content_area)
 			} else tmp.index <- which(SGP::SGPstateData[[state]][["SGP_Configuration"]][["grade.projection.sequence"]][[tmp.domain]] == grade)
 			return(SGP::SGPstateData[[state]][["SGP_Configuration"]][["content_area.projection.sequence"]][[tmp.domain]][tmp.index + increment])
@@ -446,6 +447,16 @@ if ("studentGrowthPlot" %in% plot.types) {
 			sgPlot.fan <- SGP::SGPstateData[[state]][['SGP_Configuration']][['sgPlot.fan']]
 		}
 
+		if (identical(sgPlot.custom.trajectory, TRUE)) {
+			my.custom.trajectory <- "ISR_CUSTOM_DATA"
+		}
+		if (identical(sgPlot.custom.trajectory, FALSE)) {
+			my.custom.trajectory <- NULL
+		}
+		if (!is.null(SGP::SGPstateData[[state]][['SGP_Configuration']][['sgPlot.custom.trajectory']])) {
+			my.custom.trajectory <- SGP::SGPstateData[[state]][['SGP_Configuration']][['sgPlot.custom.trajectory']]
+		}
+
 		if (!is.null(SGP::SGPstateData[[state]][['SGP_Configuration']][['sgPlot.plot.test.transition']])) {
 			sgPlot.plot.test.transition <- SGP::SGPstateData[[state]][['SGP_Configuration']][['sgPlot.plot.test.transition']]
 		}
@@ -464,11 +475,11 @@ if ("studentGrowthPlot" %in% plot.types) {
 				sgPlot.sgp.targets <- NULL
 			}
 		}
-		if (!is.null(sgPlot.sgp.targets) & !sgPlot.baseline && !all(sgPlot.sgp.targets %in% c("sgp.projections", "sgp.projections.lagged"))) {
+		if (!is.null(sgPlot.sgp.targets) & !sgPlot.baseline && !all(sgPlot.sgp.targets %in% c("sgp.projections", "sgp.projections.lagged", "CUSTOM"))) {
 			messageSGP("\tNOTE: 'sgPlot.sgp.targets' must consist of 'sgp.projections' and/or 'sgp.projections.lagged'.")
 			sgPlot.sgp.targets <- NULL
 		}
-		if (!is.null(sgPlot.sgp.targets) & sgPlot.baseline && !all(sgPlot.sgp.targets %in% c("sgp.projections.baseline", "sgp.projections.lagged.baseline"))) {
+		if (!is.null(sgPlot.sgp.targets) & sgPlot.baseline && !all(sgPlot.sgp.targets %in% c("sgp.projections.baseline", "sgp.projections.lagged.baseline", "CUSTOM"))) {
 			messageSGP("\tNOTE: 'sgPlot.sgp.targets' must consist of 'sgp.projections.baseline' and/or 'sgp.projections.lagged.baseline'.")
 			sgPlot.sgp.targets <- NULL
 		}
@@ -479,14 +490,14 @@ if ("studentGrowthPlot" %in% plot.types) {
 			my.sgp.targets <- grep(paste(sgPlot.sgp.targets.timeframe, "YEAR", sep="_"), grep("SCALE_SCORE", grep("BASELINE", grep("SGP_TARGET", names(slot.data), value=TRUE), value=TRUE), value=TRUE, invert=TRUE), value=TRUE)
 			if (identical("sgp.projections.baseline", sgPlot.sgp.targets)) my.sgp.targets <- grep("CURRENT", my.sgp.targets, value=TRUE)
 			if (identical("sgp.projections.lagged.baseline", sgPlot.sgp.targets)) my.sgp.targets <- grep("CURRENT", my.sgp.targets, value=TRUE, invert=TRUE)
-			if (is.null(sgPlot.sgp.targets)) my.sgp.targets <- NULL
+			if (is.null(sgPlot.sgp.targets) || identical(sgPlot.sgp.targets, "CUSTOM")) my.sgp.targets <- NULL
 		} else {
 			my.sgp <- "SGP"
 			my.sgp.level <- "SGP_LEVEL"
 			my.sgp.targets <- grep(paste(sgPlot.sgp.targets.timeframe, "YEAR", sep="_"), grep("SCALE_SCORE", grep("BASELINE", grep("SGP_TARGET", names(slot.data), value=TRUE), value=TRUE, invert=TRUE), value=TRUE, invert=TRUE), value=TRUE)
 			if (identical("sgp.projections", sgPlot.sgp.targets)) my.sgp.targets <- grep("CURRENT", my.sgp.targets, value=TRUE)
 			if (identical("sgp.projections.lagged", sgPlot.sgp.targets)) my.sgp.targets <- grep("CURRENT", my.sgp.targets, value=TRUE, invert=TRUE)
-			if (is.null(sgPlot.sgp.targets)) my.sgp.targets <- NULL
+			if (is.null(sgPlot.sgp.targets) || identical(sgPlot.sgp.targets, "CUSTOM")) my.sgp.targets <- NULL
 		}
 
 		if (!is.null(my.sgp.targets)) sgPlot.sgp.targets.timeframe <- as.numeric(rev(unlist(strsplit(unlist(strsplit(my.sgp.targets[1], "_YEAR"))[1], "_")))[1])
@@ -877,7 +888,7 @@ if (sgPlot.wide.data) { ### When WIDE data is provided
 	#### Reshape data (NOT NECESSARY IF WIDE data is provided)
 
 		variables.to.keep <- c("VALID_CASE", "ID", "LAST_NAME", "FIRST_NAME", "CONTENT_AREA", "CONTENT_AREA_LABELS", "YEAR", "GRADE", "SCALE_SCORE", "TRANSFORMED_SCALE_SCORE",
-			"ACHIEVEMENT_LEVEL", my.sgp, my.sgp.level, my.sgp.targets, "SCHOOL_NAME", "SCHOOL_NUMBER", "DISTRICT_NAME", "DISTRICT_NUMBER")
+			"ACHIEVEMENT_LEVEL", my.sgp, my.sgp.level, my.sgp.targets, my.custom.trajectory, "SCHOOL_NAME", "SCHOOL_NUMBER", "DISTRICT_NAME", "DISTRICT_NUMBER")
 		if (!is.null(tmp.sgPlot.id <- SGP::SGPstateData[[state]][["SGP_Configuration"]][["sgPlot.use.alternate.student.id"]])) variables.to.keep <- c(variables.to.keep, tmp.sgPlot.id)
 
 		sgPlot.data <- data.table(tmp.table[,setdiff(variables.to.keep, "VALID_CASE"), with=FALSE], key=c("ID", "CONTENT_AREA", "YEAR"))
@@ -892,6 +903,7 @@ if (sgPlot.wide.data) { ### When WIDE data is provided
 			paste("SCHOOL_NAME", tmp.last.year, sep="."), paste("SCHOOL_NUMBER", tmp.last.year, sep="."),
 			paste("DISTRICT_NAME", tmp.last.year, sep="."), paste("DISTRICT_NUMBER", tmp.last.year, sep="."))
 		if (!is.null(my.sgp.targets)) variables.to.keep <- c(variables.to.keep, paste(my.sgp.targets, tmp.last.year, sep="."))
+		if (!is.null(my.custom.trajectory)) variables.to.keep <- c(variables.to.keep, paste(my.custom.trajectory, tmp.last.year, sep="."))
 		if (!is.null(tmp.sgPlot.id)) {
 			setnames(sgPlot.data, paste(tmp.sgPlot.id, tmp.last.year, sep="."), tmp.sgPlot.id)
 			variables.to.keep <- c(tmp.sgPlot.id, variables.to.keep)
